@@ -64,7 +64,6 @@ bool checkForDir(const QString & dir);
 // last game info
 extern QList<QVariant> lastGameStartArgs;
 extern GameType lastGameType;
-extern QString lastTrainingSubFolder;
 extern GameCFGWidget * lastGameCfg;
 extern QString lastGameAmmo;
 extern TeamSelWidget * lastGameTeamSel;
@@ -77,10 +76,11 @@ class HWGame : public TCPBase
         virtual ~HWGame();
         void AddTeam(const QString & team);
         void PlayDemo(const QString & demofilename, bool isSave);
+        void PlayOfficialServerDemo();
         void StartLocal();
         void StartQuick();
         void StartNet();
-        void StartTraining(const QString & file, const QString & subFolder);
+        void StartTraining(const QString & file, const QString & subFolder, const QString & trainTeam);
         void StartCampaign(const QString & camp, const QString & campScript, const QString & campTeam);
         void abort();
         GameState gameState;
@@ -96,10 +96,12 @@ class HWGame : public TCPBase
         void SendChat(const QString & msg);
         void SendTeamMessage(const QString & msg);
         void GameStateChanged(GameState gameState);
+        void DemoPresenceChanged(bool hasDemo);
         void GameStats(char type, const QString & info);
         void HaveRecord(RecordType type, const QByteArray & record);
         void ErrorMessage(const QString &);
         void CampStateChanged(int);
+        void TrainingStateChanged(int);
         void SendConsoleCommand(const QString & command);
 
     public slots:
@@ -125,8 +127,11 @@ class HWGame : public TCPBase
         void SendCampaignConfig();
         void ParseMessage(const QByteArray & msg);
         void SetGameState(GameState state);
+        void SetDemoPresence(bool hasDemo);
         void sendCampaignVar(const QByteArray & varToSend);
         void writeCampaignVar(const QByteArray &varVal);
+        void sendMissionVar(const QByteArray & varToSend);
+        void writeMissionVar(const QByteArray &varVal);
         void flushNetBuffer();
 };
 
