@@ -291,27 +291,14 @@ int main(int argc, char *argv[]) {
         // end of parameter parsing
 
         // Select Qt style
-        /* Qt5 Base removed Motif, Plastique. These are now in the Qt style plugins
-        (Ubuntu: qt5-style-plugins, which was NOT backported by Debian/Ubuntu to stable/LTS).
-        Windows appears to render best of the remaining options but still isn't quite right. */
-
-        // Try setting Plastique if available
         QStyle* coreStyle;
-        coreStyle = QStyleFactory::create("Plastique");
+        coreStyle = QStyleFactory::create("Windows");
         if(coreStyle != 0) {
             QApplication::setStyle(coreStyle);
-            qDebug("Qt style set: Plastique");
+            qDebug("Qt style set: Windows");
         } else {
-            // Use Windows as fallback.
-            // FIXME: Under Windows style, some widgets like scrollbars don't render as nicely
-            coreStyle = QStyleFactory::create("Windows");
-            if(coreStyle != 0) {
-                QApplication::setStyle(coreStyle);
-                qDebug("Qt style set: Windows");
-            } else {
-                // Windows style should not be missing in Qt5 Base. If it does, something went terribly wrong!
-                qWarning("No Qt style could be set! Using the default one.");
-            }
+            // Windows style should not be missing in Qt5 Base. If it does, something went terribly wrong!
+            qWarning("No Qt style could be set! Using the default one.");
         }
     }
 
@@ -341,10 +328,10 @@ int main(int argc, char *argv[]) {
         checkForDir(cfgdir->absolutePath() + "/Library/Application Support/Hedgewars");
         cfgdir->cd("Library/Application Support/Hedgewars");
 #elif defined _WIN32
-        char path[1024];
-        if(!SHGetFolderPathA(0, CSIDL_PERSONAL, NULL, 0, path))
+        wchar_t path[MAX_PATH];
+        if(SHGetFolderPathW(0, CSIDL_PERSONAL, NULL, 0, path) == S_OK)
         {
-            cfgdir->cd(path);
+            cfgdir->cd(QString::fromWCharArray(path));
             checkForDir(cfgdir->absolutePath() + "/Hedgewars");
             cfgdir->cd("Hedgewars");
         }
@@ -373,6 +360,7 @@ int main(int argc, char *argv[]) {
         checkForDir(cfgdir->absolutePath() + "/Logs");
         checkForDir(cfgdir->absolutePath() + "/Videos");
         checkForDir(cfgdir->absolutePath() + "/VideoTemp");
+        checkForDir(cfgdir->absolutePath() + "/VideoThumbnails");
     }
 
     datadir->cd(bindir->absolutePath());
@@ -395,10 +383,9 @@ int main(int argc, char *argv[]) {
 
     QTranslator TranslatorHedgewars;
     QTranslator TranslatorQt;
+    QSettings settings(DataManager::instance().settingsFileName(), QSettings::IniFormat);
+    settings.setIniCodec("UTF-8");
     {
-        QSettings settings(DataManager::instance().settingsFileName(), QSettings::IniFormat);
-        settings.setIniCodec("UTF-8");
-
         QString cc = settings.value("misc/locale", QString()).toString();
         if (cc.isEmpty())
         {
@@ -494,11 +481,16 @@ int main(int argc, char *argv[]) {
     QString style = "";
     QString fname;
 
-    checkSeason();
-    //For each season, there is an extra stylesheet
-    //Todo: change background for easter and birthday
-    //(simply replace res/BackgroundBirthday.png and res/BackgroundEaster.png
-    //with an appropriate background
+    bool holidaySilliness = settings.value("misc/holidaySilliness", true).toBool();
+    if(holidaySilliness)
+        checkSeason();
+    else
+        season = SEASON_NONE;
+
+    // For each season, there is an extra stylesheet.
+    // TODO: change background for easter
+    // (simply replace res/BackgroundEaster.png
+    // with an appropriate background).
     switch (season)
     {
         case SEASON_CHRISTMAS :
@@ -544,6 +536,7 @@ int main(int argc, char *argv[]) {
         questionTutorialMsg.setIcon(QMessageBox::Question);
         questionTutorialMsg.setWindowTitle(QMessageBox::tr("Welcome to Hedgewars"));
         questionTutorialMsg.setText(QMessageBox::tr("Welcome to Hedgewars!\n\nYou seem to be new around here. Would you like to play some training missions first to learn the basics of Hedgewars?"));
+        questionTutorialMsg.setTextFormat(Qt::PlainText);
         questionTutorialMsg.setWindowModality(Qt::WindowModal);
         questionTutorialMsg.addButton(QMessageBox::Yes);
         questionTutorialMsg.addButton(QMessageBox::No);
