@@ -34,10 +34,12 @@ QLayout * PageMultiplayer::bodyLayoutDefinition()
     QHBoxLayout * pageLayout = new QHBoxLayout();
 
     gameCFG = new GameCFGWidget(this);
-    pageLayout->addWidget(gameCFG, 3, Qt::AlignTop);
+    pageLayout->addWidget(gameCFG);
+    pageLayout->setAlignment(gameCFG, Qt::AlignTop);
 
     teamsSelect = new TeamSelWidget(this);
-    pageLayout->addWidget(teamsSelect, 2, Qt::AlignTop);
+    pageLayout->addWidget(teamsSelect);
+    teamsSelect->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
 
     return pageLayout;
 }
@@ -46,7 +48,7 @@ QLayout * PageMultiplayer::footerLayoutLeftDefinition()
 {
     QHBoxLayout * bottomLeftLayout = new QHBoxLayout();
 
-    btnSetup = addButton(":/res/Settings.png", bottomLeftLayout, 0, true);
+    btnSetup = addButton(":/res/Settings.png", bottomLeftLayout, 0, true, Qt::AlignBottom);
     btnSetup->setWhatsThis(tr("Edit game preferences"));
 
     return bottomLeftLayout;
@@ -59,16 +61,17 @@ QLayout * PageMultiplayer::footerLayoutDefinition()
     const QIcon& lp = QIcon(":/res/Start.png");
     QSize sz = lp.actualSize(QSize(65535, 65535));
     BtnStartMPGame = new QPushButton();
+    BtnStartMPGame->setStyleSheet("padding: 5px 10px");
     BtnStartMPGame->setText(tr("Start"));
-    BtnStartMPGame->setMinimumWidth(sz.width() + 60);
+    BtnStartMPGame->setWhatsThis(tr("Start fighting (requires at least 2 teams)"));
     BtnStartMPGame->setIcon(lp);
     BtnStartMPGame->setFixedHeight(50);
     BtnStartMPGame->setIconSize(sz);
     BtnStartMPGame->setFlat(true);
-    BtnStartMPGame->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+    BtnStartMPGame->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
 
     footerLayout->addStretch();
-    footerLayout->addWidget(BtnStartMPGame);
+    footerLayout->addWidget(BtnStartMPGame, 0, Qt::AlignBottom);
 
     return footerLayout;
 }
