@@ -201,8 +201,7 @@ HWChatWidget::HWChatWidget(QWidget* parent, bool notify) :
     mainLayout.setMargin(0);
 
     QWidget * leftSideContainer = new QWidget();
-    leftSideContainer->setObjectName("leftSideContainer");
-    leftSideContainer->setStyleSheet("#leftSideContainer { border-width: 0px; background-color: #ffcc00; border-radius: 10px;} QTextBrowser, SmartLineEdit { background-color: rgb(13, 5, 68); }");
+    leftSideContainer->setObjectName("chatContainer");
     QVBoxLayout * leftSide = new QVBoxLayout(leftSideContainer);
     leftSide->setSpacing(3);
     leftSide->setMargin(3);
@@ -217,7 +216,7 @@ HWChatWidget::HWChatWidget(QWidget* parent, bool notify) :
     chatText->setMinimumWidth(10);
     chatText->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     chatText->setOpenLinks(false);
-    chatText->setStyleSheet("QTextBrowser { background-color: rgb(23, 11, 54); border-width: 0px; }");
+    chatText->setObjectName("chatText");
     connect(chatText, SIGNAL(anchorClicked(const QUrl&)),
             this, SLOT(linkClicked(const QUrl&)));
     leftSide->addWidget(chatText, 1);
@@ -521,10 +520,18 @@ void HWChatWidget::nickAdded(const QString & nick, bool notifyNick)
     if (!isIgnored)
         printChatString(nick, QString("*** ") + tr("%1 has joined").arg(linkedNick(nick)), "Join", false);
 
-    if (notifyNick && notify && (m_helloSounds.size() > 0))
+    if (notifyNick && notify)
     {
-        SDLInteraction::instance().playSoundFile(
+        if (m_helloSounds.size() > 0)
+        {
+            SDLInteraction::instance().playSoundFile(
                             m_helloSounds.at(rand() % m_helloSounds.size()));
+        }        
+
+        if (!isInGame())
+        {
+            HWApplication::alert(this, 2000);
+        }
     }
 }
 
