@@ -326,7 +326,8 @@ handleCmd_inRoom ["ROOM_NAME", newName] = roomAdminOnly $ do
             [Warning $ loc "A room with the same name already exists."]
         else
             [ModifyRoom roomUpdate,
-            AnswerClients chans ("ROOM" : "UPD" : name rm : roomInfo (clientProto cl) (nick cl) (roomUpdate rm))]
+            AnswerClients chans ("ROOM" : "UPD" : name rm : roomInfo (clientProto cl) (nick cl) (roomUpdate rm)),
+            RegisterEvent RoomNameUpdate]
     where
         roomUpdate r = r{name = newName}
 
@@ -382,7 +383,7 @@ handleCmd_inRoom ["TEAMCHAT", msg] = do
     where
         -- This is formatted in a way so it can parsed by engine to make it translatable
         -- Format: b<PLAYER NAME>]<MESSAGE>
-        engineMsg cl = toEngineMsg $ B.concat ["b", nick cl, "]", msg]
+        engineMsg cl = toEngineMsg $ B.concat ["b", nick cl, "]", msg, "\x20\x20"]
 
 
 handleCmd_inRoom ["BAN", banNick] = do
@@ -452,7 +453,7 @@ handleCmd_inRoom ["GREETING", msg] = do
 handleCmd_inRoom ["CALLVOTE"] = do
     cl <- thisClient
     return [AnswerClients [sendChan cl]
-        ["CHAT", nickServer, loc "Available callvote commands: kick <nickname>, map <name>, pause, newseed, hedgehogs"]
+        ["CHAT", nickServer, loc "Available callvote commands: hedgehogs <number>, pause, newseed, map <name>, kick <player>"]
         ]
 
 handleCmd_inRoom ["CALLVOTE", "KICK"] = do
