@@ -220,12 +220,18 @@ handleCmd_lobby ["GET_SERVER_VAR"] = serverAdminOnly $
 handleCmd_lobby ["CLEAR_ACCOUNTS_CACHE"] = serverAdminOnly $
     return [ClearAccountsCache]
 
-handleCmd_lobby ["RESTART_SERVER"] = serverAdminOnly $
+handleCmd_lobby ["RESTART_SERVER", "YES"] = serverAdminOnly $
     return [RestartServer]
 
+handleCmd_lobby ["RESTART_SERVER"] = serverAdminOnly $
+    return [Warning $ loc "Please confirm server restart with '/restart_server yes'."]
+
+handleCmd_lobby ["RESTART_SERVER", _] = handleCmd_lobby ["RESTART_SERVER"]
+
+
 handleCmd_lobby ["STATS"] = serverAdminOnly $
     return [Stats]
 
 handleCmd_lobby (s:_) = return [ProtocolError $ "Incorrect command '" `B.append` s `B.append` "' (state: in lobby)"]
 
-handleCmd_lobby [] = return [ProtocolError "Empty command (state: in lobby)"]
\ No newline at end of file
+handleCmd_lobby [] = return [ProtocolError "Empty command (state: in lobby)"]
