@@ -186,7 +186,8 @@ void fpcrtl_blockRead__vars(File f, void *buf, Integer count, Integer *result) {
  */
 void fpcrtl_blockWrite__vars(File f, const void *buf, Integer count,
         Integer *result) {
-    assert(0);
+    assert(f->record_len > 0);
+    *result = fwrite(buf, f->record_len, count, f->fp);
 }
 
 bool fpcrtl_directoryExists(string255 dir) {
@@ -240,3 +241,35 @@ void __attribute__((overloadable)) fpcrtl_flush(FILE *f) {
     fflush(f);
 }
 
+Int64 fpcrtl_fileSize(File f)
+{
+    assert(f->record_len > 0);
+
+    IOResult = IO_NO_ERROR;
+    int i = fseek(f->fp, 0, SEEK_END);
+    if (i == -1) {
+        IOResult = IO_ERROR_DUMMY;
+        return -1;
+    }
+    long size = ftell(f->fp);
+    if (size == -1) {
+        IOResult = IO_ERROR_DUMMY;
+        return -1;
+    }
+    return size / f->record_len;
+}
+
+bool fpcrtl_deleteFile(string255 filename)
+{
+    FIX_STRING(filename);
+
+    int ret = remove(filename.str);
+    if(ret == 0) {
+       IOResult = IO_NO_ERROR;
+       return true;
+    } else {
+       IOResult = IO_ERROR_DUMMY;
+       return false;
+    }
+}
+
